#
# spec file for package python-kafka-python
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-kafka-python
Version:        1.0.1
Release:        2.3
Summary:        Pure Python client for Apache Kafka
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/mumrah/kafka-python
Source:         https://pypi.io/packages/source/k/kafka-python/kafka-python-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python-six
Requires:       python-six
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
This module provides low-level protocol support for Apache Kafka as well as
high-level consumer and producer classes. Request batching is supported by the
protocol as well as broker-aware request routing. Gzip and Snappy compression
is also supported for message sets.

%prep
%setup -q -n kafka-python-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc README.rst LICENSE
%{python_sitelib}/*

%changelog
* Mon Jul 11 2016 tbechtold@suse.com
- Install LICENSE
* Mon Jul  4 2016 tbechtold@suse.com
- Use pypi.io for Source url
* Mon Mar 14 2016 mmnelemane@suse.com
- Updated version to 1.0.1
  * Consumers:
  * Add RangePartitionAssignor (and use as default); add assignor tests
    (dpkp PR 550)
  * Make sure all consumers are in same generation before stopping
    group test
  * Verify node ready before sending offset fetch request from
    coordinator
  * Improve warning when offset fetch request returns unknown
    topic / partition
  * KafkaConsumer re-written to emulate the new 0.9 kafka consumer
    (java client) and support coordinated consumer groups
    (feature requires >= 0.9.0.0 brokers)
  * Methods no longer available:
  * configure [initialize a new consumer instead]
  * set_topic_partitions [use subscribe() or assign()]
  * fetch_messages [use poll() or iterator interface]
  * get_partition_offsets
  * offsets [use committed(partition)]
  * task_done [handled internally by auto-commit; or commit
    offsets manually]
  * Configuration changes (consistent with updated java client):
  * lots of new configuration parameters -- see docs for details
  * auto_offset_reset: previously values were 'smallest' or 'largest',
    now values are 'earliest' or 'latest'
  * fetch_wait_max_ms is now fetch_max_wait_ms
  * max_partition_fetch_bytes is now max_partition_fetch_bytes
  * deserializer_class is now value_deserializer and key_deserializer
  * auto_commit_enable is now enable_auto_commit
  * auto_commit_interval_messages was removed
  * socket_timeout_ms was removed
  * refresh_leader_backoff_ms was removed
  * SimpleConsumer and MultiProcessConsumer are now deprecated and will be
    removed in a future release. Users are encouraged to migrate to
    KafkaConsumer.
  * Initial support for consumer coordinator: offsets only
    (toddpalino PR 420)
  * Allow blocking until some messages are received in SimpleConsumer
    (saaros PR 457)
  * Support subclass config changes in KafkaConsumer (zackdever PR 446)
  * Support retry semantics in MultiProcessConsumer (barricadeio PR 456)
  * Support partition_info in MultiProcessConsumer (scrapinghub PR 418)
  * Enable seek() to an absolute offset in SimpleConsumer (haosdent PR 412)
  * Add KafkaConsumer.close() (ucarion PR 426)
  * Producers
  * Warn if pending batches failed during flush
  * Fix concurrency bug in RecordAccumulator.ready()
  * Fix bug in SimpleBufferPool memory condition waiting / timeout
  * Support batch_size = 0 in producer buffers (dpkp PR 558)
  * Catch duplicate batch.done() calls [e.g., maybe_expire then a response
    errback]
  * new producer class: KafkaProducer. Exposes the same interface as
    official java client. Async by default; returned future.get() can be
    called for synchronous blocking
  * SimpleProducer is now deprecated and will be removed in a future
    release. Users are encouraged to migrate to KafkaProducer.
  * Catch client.reinit() exceptions in async producer (dpkp)
  * Producer.stop() now blocks until async thread completes (dpkp PR 485)
  * Catch errors during load_metadata_for_topics in async producer
    (bschopman PR 467)
  * Add compression-level support for codecs that support it (trbs PR 454)
  * Fix translation of Java murmur2 code, fix byte encoding for Python 3
    (chrischamberlin PR 439)
  * Only call stop() on not-stopped producer objects (docker-hub PR 435)
  * Allow null payload for deletion feature (scrapinghub PR 409)
  * Clients
  * synchronous KafkaClient renamed to SimpleClient. For backwards
    compatibility, you will get a SimpleClient via
    `from kafka import KafkaClient`. This will change in a future release.
  * All client calls use non-blocking IO under the hood.
  * Add probe method check_version() to infer broker versions.
  * Use non-blocking io for broker aware requests (ecanzonieri PR 473)
  * Use debug logging level for metadata request (ecanzonieri PR 415)
  * Catch KafkaUnavailableError in _send_broker_aware_request
    (mutability PR 436)
  * Lower logging level on replica not available and commit
    (ecanzonieri PR 415)
  * Documentation
  * Improve kafka.cluster docstrings
  * Migrate load_example.py to KafkaProducer / KafkaConsumer
  * Updated README and sphinx documentation to address new classes.
  * Docstring improvements to make python help() easier to use.
  * Update docs and links wrt maintainer change (mumrah -> dpkp)
  * Internals
  * Dont override system rcvbuf or sndbuf unless configured explicitly
    (dpkp PR 557)
  * Some attributes may not exist in __del__ if we failed assertions
  * Break up some circular references and close client wake pipes on __del__
    (aisch PR 554)
  * Old protocol stack is deprecated. It has been moved to
    kafka.protocol.legacy and may be removed in a future release.
  * Protocol layer re-written using Type classes, Schemas and Structs
    (modeled on the java client).
  * Add support for LZ4 compression (including broken framing header
    checksum).
  * Add py35 to tox testing
  * Update travis config to use container infrastructure
  * Add 0.8.2.2 and 0.9.0.0 resources for integration tests; update default
    official releases
  * new pylint disables for pylint 1.5.1 (zackdever PR 481)
  * Fix python3 / python2 comments re queue/Queue (dpkp)
  * Add Murmur2Partitioner to kafka __all__ imports (dpkp Issue 471)
  * Include LICENSE in PyPI sdist (koobs PR 441)
* Wed Sep 16 2015 tbechtold@suse.com
- Initial packaging (version 0.9.4)
